@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgConn.cpp,v 1.60 2004/11/21 14:19:41 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgConn.cpp,v 1.60.2.3 2005/03/18 21:08:41 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgConn.cpp - PostgreSQL Connection class
@@ -51,7 +51,7 @@ static void pgNoticeProcessor(void *arg, const char *message)
 pgConn::pgConn(const wxString& server, const wxString& database, const wxString& username, const wxString& password, int port, int sslmode, OID oid)
 {
     wxLogInfo(wxT("Creating pgConn object"));
-    wxString msg, hostip;
+    wxString msg, hostip, hostname;
 
     conv = &wxConvLibc;
     needColQuoting = false;
@@ -85,7 +85,7 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
 
         memcpy(&(ipaddr),host->h_addr,host->h_length); 
 	    hostip = wxString::FromAscii(inet_ntoa(*((struct in_addr*) host->h_addr_list[0])));
-
+		hostname = server;
     }
     else
         hostip = server;
@@ -94,6 +94,10 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
 
     // Create the connection string
     wxString connstr;
+    if (!hostname.IsEmpty()) {
+      connstr.Append(wxT(" host="));
+      connstr.Append(qtString(hostname));
+    }
     if (!server.IsEmpty()) {
       connstr.Append(wxT(" hostaddr="));
       connstr.Append(qtString(hostip));
@@ -237,7 +241,24 @@ void pgConn::RegisterNoticeProcessor(PQnoticeProcessor proc, void *arg)
 
 wxString pgConn::SystemNamespaceRestriction(const wxString &nsp)
 {
-    return wxT("(") + nsp + wxT(" NOT LIKE 'pg\\_%' AND ") + nsp + wxT(" NOT LIKE 'information_schema')");
+    if (reservedNamespaces.IsEmpty())
+    {
+        reservedNamespaces = wxT("'information_schema'");
+        pgSet *set=ExecuteSet(
+                wxT("SELECT nspname FROM pg_namespace nsp\n")
+                wxT("  JOIN pg_proc pr ON pronamespace=nsp.oid\n")
+                wxT(" WHERE proname IN ('slonyversion')"));
+        if (set)
+        {
+            while (!set->Eof())
+            {
+                reservedNamespaces += wxT(", ") + qtString(set->GetVal(wxT("nspname")));
+                set->MoveNext();
+            }
+            delete set;
+        }
+    }
+    return wxT("(") + nsp + wxT(" NOT LIKE 'pg\\_%' AND ") + nsp + wxT(" NOT in (") + reservedNamespaces + wxT("))");
 }
 
 
@@ -412,6 +433,12 @@ bool pgConn::IsAlive()
 
     PGresult *qryRes = PQexec(conn, "SELECT 1;");
     lastResultStatus = PQresultStatus(qryRes);
+    if (lastResultStatus != PGRES_TUPLES_OK)
+    {
+        PQclear(qryRes);
+        qryRes = PQexec(conn, "ROLLBACK TRANSACTION; SELECT 1;");
+        lastResultStatus = PQresultStatus(qryRes);
+    }
     PQclear(qryRes);
 
     // Check for errors
