@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgColumn.h,v 1.10 2004/07/20 12:38:04 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgColumn.h,v 1.10.2.2 2005/03/19 21:29:35 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgColumn.h - Column property 
@@ -29,6 +29,8 @@ public:
     pgObject *GetObject();
     wxString GetDefinition();
     wxString GetPreviousDefinition() { return previousDefinition; }
+	wxString GetComment() {	return txtComment->GetValue(); }
+	wxString GetStatistics() {	return CTRL_TEXT("txtAttstattarget")->GetValue(); }
 
     int Go(bool modal);
 
