@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgProperty.h,v 1.41 2004/11/02 16:12:06 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgProperty.h,v 1.41.2.2 2005/03/04 21:15:52 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgProperty.h - common property dialog class
@@ -56,7 +56,7 @@ protected:
 
     void CheckValid(bool &enable, const bool condition, const wxString &msg);
     static dlgProperty *CreateDlg(frmMain *frame, pgObject *node, bool asNew, int type=-1);
-    void AppendNameChange(wxString &sql);
+    void AppendNameChange(wxString &sql, const wxString &objname=wxEmptyString);
     void AppendOwnerChange(wxString &sql, const wxString &objName=wxEmptyString);
     void AppendOwnerNew(wxString &sql, const wxString &objname);
     void AppendComment(wxString &sql, const wxString &objType, pgSchema *schema, pgObject *obj);
