@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgCast.h,v 1.19 2004/01/02 23:15:00 dpage Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgCast.h,v 1.19.2.2 2005/02/13 15:13:06 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgCast.h PostgreSQL Cast
@@ -38,6 +38,10 @@ public:
     void iSetSourceType(const wxString& s) { sourceType=s; }
     wxString GetTargetType() const { return targetType; }
     void iSetTargetType(const wxString& s) { targetType=s; }
+    wxString GetSourceNamespace() const { return sourceNamespace; }
+    void iSetSourceNamespace(const wxString& s) { sourceNamespace=s; }
+    wxString GetTargetNamespace() const { return targetNamespace; }
+    void iSetTargetNamespace(const wxString& s) { targetNamespace=s; }
     OID GetSourceTypeOid() const { return sourceTypeOid; }
     void iSetSourceTypeOid(const OID o) { sourceTypeOid=o; }
     OID GetTargetTypeOid() const { return targetTypeOid; }
@@ -55,7 +59,8 @@ public:
     pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
 
 private:
-    wxString sourceType, targetType, castFunction, castContext, castNamespace;
+    wxString sourceType, sourceNamespace, targetType, targetNamespace, 
+             castFunction, castContext, castNamespace;
     OID sourceTypeOid, targetTypeOid;
 };
 
