@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSequence.h,v 1.17 2004/06/19 19:18:01 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgSequence.h,v 1.17.2.2 2005/02/07 14:52:28 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgSequence.h PostgreSQL Sequence
@@ -34,8 +34,6 @@ public:
     void ShowStatistics(frmMain *form, ctlListView *statistics);
     static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
 
-    wxString GetTablespace() const { return tablespace; };
-    void iSetTablespace(const wxString& newVal) { tablespace = newVal; }
     void UpdateValues();
     wxULongLong GetLastValue() const { return lastValue; }
     wxULongLong GetMinValue() const { return minValue; }
@@ -51,7 +49,6 @@ public:
 private:
     wxULongLong lastValue, minValue, maxValue, cacheValue, increment;
     bool cycled;
-    wxString tablespace;
 };
 
 #endif
