@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgColumn.cpp,v 1.38 2004/07/27 10:36:01 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgColumn.cpp,v 1.38.2.2 2005/03/26 21:19:37 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgColumn.cpp - Column class
@@ -162,7 +162,8 @@ void pgColumn::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *p
         // fk, pk lesen
         pgSet *set = ExecuteSet(
             wxT("SELECT indkey FROM pg_index\n")
-            wxT(" WHERE indrelid=") + GetTableOidStr());
+            wxT(" WHERE indrelid=") + GetTableOidStr() +
+			wxT(" AND indisprimary"));
         if (set)
         {
             wxString indkey, str;
