@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDomain.cpp,v 1.23 2004/10/08 13:52:19 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgDomain.cpp,v 1.23.2.4 2005/03/25 21:54:37 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgDomain.cpp - Domain class
@@ -47,7 +47,7 @@ wxString pgDomain::GetSql(wxTreeCtrl *browser)
         // CONSTRAINT Name Dont know where it's stored, may be omitted anyway
         if (notNull)
             sql += wxT("\n  NOT NULL");
-        AppendIfFilled(sql, wxT("\n   CHECK "), GetCheck());
+        AppendIfFilled(sql, wxT("\n   "), GetCheck());
 
         sql += wxT(";\n")
             + GetOwnerSql(7, 4)
@@ -150,7 +150,7 @@ pgObject *pgDomain::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, c
             domain->iSetOid(domains->GetOid(wxT("oid")));
             domain->iSetOwner(domains->GetVal(wxT("domainowner")));
             domain->iSetBasetype(domains->GetVal(wxT("basetype")));
-            domain->iSetBasetypeOid(domains->GetBool(wxT("typbasetype")));
+            domain->iSetBasetypeOid(domains->GetOid(wxT("typbasetype")));
             domain->iSetComment(domains->GetVal(wxT("description")));
             long typmod=domains->GetLong(wxT("typtypmod"));
 
