@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSequence.cpp,v 1.28 2004/10/08 13:52:19 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgSequence.cpp,v 1.28.2.2 2005/02/07 14:52:28 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgSequence.cpp - Sequence class
@@ -69,7 +69,7 @@ wxString pgSequence::GetSql(wxTreeCtrl *browser)
             + wxT("\n  CACHE ") + GetCacheValue().ToString();
         if (GetCycled())
             sql += wxT("\n  CYCLE");
-        AppendIfFilled(sql, wxT("\n  TABLESPACE "), qtIdent(tablespace));
+
         sql += wxT(";\n")
             + GetOwnerSql(7, 3, wxT("TABLE ") + GetQuotedFullIdentifier())
             + GetGrant(wxT("arwdRxt"), wxT("TABLE ") + GetQuotedFullIdentifier())
@@ -89,8 +89,6 @@ void pgSequence::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
         properties->AppendItem(_("Name"), GetName());
         properties->AppendItem(_("OID"), GetOid());
         properties->AppendItem(_("Owner"), GetOwner());
-        if (!tablespace.IsEmpty())
-            properties->AppendItem(_("Tablespace"), tablespace);
         properties->AppendItem(_("ACL"), GetAcl());
         properties->AppendItem(_("Current value"), GetLastValue());
         properties->AppendItem(_("Minimum"), GetMinValue());
@@ -147,27 +145,14 @@ pgObject *pgSequence::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
     pgSequence *sequence=0;
 
     pgSet *sequences;
-    if (collection->GetConnection()->BackendMinimumVersion(7, 5))
-    {
-        sequences = collection->GetDatabase()->ExecuteSet(
-            wxT("SELECT cl.oid, relname, spcname, pg_get_userbyid(relowner) AS seqowner, relacl, description\n")
-            wxT("  FROM pg_class cl\n")
-            wxT("  LEFT OUTER JOIN pg_tablespace ta on ta.oid=cl.reltablespace\n")
-            wxT("  LEFT OUTER JOIN pg_description des ON des.objoid=cl.oid\n")
-            wxT(" WHERE relkind = 'S' AND relnamespace  = ") + collection->GetSchema()->GetOidStr()
-            + restriction + wxT("\n")
-            wxT(" ORDER BY relname"));
-    }
-    else
-    {
-        sequences = collection->GetDatabase()->ExecuteSet(
+    sequences = collection->GetDatabase()->ExecuteSet(
             wxT("SELECT cl.oid, relname, pg_get_userbyid(relowner) AS seqowner, relacl, description\n")
             wxT("  FROM pg_class cl\n")
             wxT("  LEFT OUTER JOIN pg_description des ON des.objoid=cl.oid\n")
             wxT(" WHERE relkind = 'S' AND relnamespace  = ") + collection->GetSchema()->GetOidStr()
             + restriction + wxT("\n")
             wxT(" ORDER BY relname"));
-    }
+
     if (sequences)
     {
         while (!sequences->Eof())
@@ -179,8 +164,6 @@ pgObject *pgSequence::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
             sequence->iSetComment(sequences->GetVal(wxT("description")));
             sequence->iSetOwner(sequences->GetVal(wxT("seqowner")));
             sequence->iSetAcl(sequences->GetVal(wxT("relacl")));
-            if (collection->GetConnection()->BackendMinimumVersion(7, 5))
-                sequence->iSetTablespace(sequences->GetVal(wxT("spcname")));
 
             if (browser)
             {
