@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTrigger.cpp,v 1.25 2004/01/02 23:15:00 dpage Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: pgTrigger.cpp,v 1.25.2.2 2005/02/09 14:33:56 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgTrigger.cpp - Trigger class
@@ -59,8 +59,8 @@ wxString pgTrigger::GetSql(wxTreeCtrl *browser)
     if (sql.IsNull() && this->triggerFunction)
     {
         sql = wxT("-- Trigger: ") + GetName() + wxT(" on ") + GetQuotedFullTable() + wxT("\n\n")
-            + wxT("-- DROP TRIGGER ") + GetName()
-            + wxT(" ON ") + GetQuotedFullTable() +wxT(";\n\nCREATE TRIGGER ") + GetName()
+            + wxT("-- DROP TRIGGER ") + qtIdent(GetName())
+            + wxT(" ON ") + GetQuotedFullTable() +wxT(";\n\nCREATE TRIGGER ") + qtIdent(GetName())
             + wxT("\n  ") + GetFireWhen() 
             + wxT(" ") + GetEvent()
             + wxT("\n  ON ") + GetQuotedFullTable()
