@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgAggregate.cpp,v 1.21 2004/11/09 13:41:41 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgAggregate.cpp,v 1.21.2.2 2005/03/04 21:15:52 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgAggregate.cpp - PostgreSQL Operator Property
@@ -210,8 +210,10 @@ wxString dlgAggregate::GetSql()
     if (aggregate)
     {
         // edit mode
-        AppendNameChange(sql);
-        AppendOwnerChange(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(name));
+        AppendNameChange(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(aggregate->GetName()) + 
+							   wxT("(") + GetQuotedTypename(cbBaseType->GetGuessedSelection()) + wxT(")"));
+        AppendOwnerChange(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(GetName()) + 
+							   wxT("(") + GetQuotedTypename(cbBaseType->GetGuessedSelection()) + wxT(")"));
     }
     else
     {
@@ -233,11 +235,12 @@ wxString dlgAggregate::GetSql()
         
         sql += wxT(");\n");
 
-        AppendOwnerNew(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(name));
+        AppendOwnerNew(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(name)+ 
+			                wxT("(") + GetQuotedTypename(cbBaseType->GetGuessedSelection()) + wxT(")"));
     }
     AppendComment(sql, wxT("AGGREGATE ") + schema->GetQuotedPrefix() + qtIdent(name)
                   + wxT("(") + GetQuotedTypename(cbBaseType->GetGuessedSelection())
-                  +wxT(")"), aggregate);
+                  + wxT(")"), aggregate);
 
     return sql;
 }
