@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgProperty.cpp,v 1.106 2004/11/09 13:41:41 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgProperty.cpp,v 1.106.2.2 2005/03/04 21:15:52 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgQuery.cpp - Property Dialog
@@ -251,13 +251,22 @@ wxString dlgProperty::GetName()
 }
 
 
-void dlgProperty::AppendNameChange(wxString &sql)
+void dlgProperty::AppendNameChange(wxString &sql, const wxString &objName)
 {
     if (GetObject()->GetName() != GetName())
-        sql += wxT("ALTER ") + GetObject()->GetTypeName()
-            +  wxT(" ") + GetObject()->GetQuotedFullIdentifier()
-            +  wxT(" RENAME TO ") + qtIdent(GetName())
-            +  wxT(";\n");
+    {
+ 		if (objName.Length() > 0)
+ 		{
+ 			sql += wxT("ALTER ") + objName
+ 				+  wxT(" RENAME TO ") + qtIdent(GetName())
+ 				+  wxT(";\n");
+ 		} else {
+ 			sql += wxT("ALTER ") + GetObject()->GetTypeName()
+ 	            +  wxT(" ") + GetObject()->GetQuotedFullIdentifier()
+ 				+  wxT(" RENAME TO ") + qtIdent(GetName())
+ 				+  wxT(";\n");
+ 		}
+    }
 }
 
 
