@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: events.cpp,v 1.119 2004/10/27 18:50:28 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: events.cpp,v 1.119.2.3 2005/02/14 13:05:09 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // events.cpp - Event handlers for frmMain
@@ -688,6 +688,10 @@ void frmMain::execSelChange(wxTreeItemId item, bool currentNode)
     if (currentNode)
     {
         properties->ClearAll();
+        statistics->ClearAll();
+        referencedBy->ClearAll();
+        dependsOn->ClearAll();
+
         properties->AddColumn(_("Properties"), 500);
         properties->InsertItem(0, _("No properties are available for the current selection"), PGICON_PROPERTY);
         sqlPane->Clear();
@@ -709,9 +713,13 @@ void frmMain::execSelChange(wxTreeItemId item, bool currentNode)
     {
         properties->Freeze();
         statistics->Freeze();
+        referencedBy->Freeze();
+        dependsOn->Freeze();
         setDisplay(currentObject, properties, sqlPane);
         properties->Thaw();
         statistics->Thaw();
+        referencedBy->Thaw();
+        dependsOn->Thaw();
     }
     else
         setDisplay(currentObject, 0, 0);
@@ -1137,7 +1145,7 @@ void frmMain::OnDrop(wxCommandEvent &ev)
 
                 if (properties->GetSelectedItemCount() == 1)
                 {
-                    dropSingleObject(data, false);
+                    dropSingleObject(data, true);
                 }
                 else
                 {
