@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMain.cpp,v 1.112 2004/11/09 14:15:43 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: frmMain.cpp,v 1.112.2.2 2005/01/10 15:30:25 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmMain.cpp - The main form
@@ -685,6 +685,7 @@ int frmMain::ReconnectServer(pgServer *server)
     switch (res)
     {
         case PGCONN_OK:
+        {
             StartMsg(_("Restoring previous environment"));
             wxLogInfo(wxT("pgServer object initialised as required."));
             browser->SetItemImage(server->GetId(), PGICON_SERVER, wxTreeItemIcon_Normal);
@@ -704,7 +705,8 @@ int frmMain::ReconnectServer(pgServer *server)
                 browser->EnsureVisible(item);
             }
             EndMsg();
-            break;
+            return res;
+        }
         case PGCONN_DNSERR:
             /*
             // looks strange to me. Shouldn_t server be removed from the tree as well?
@@ -719,6 +721,7 @@ int frmMain::ReconnectServer(pgServer *server)
             wxLogInfo(wxT("pgServer object didn't initialise because the user aborted."));
             break;
     }
+    server->Disconnect();
     return res;
 }
 
