@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: misc.cpp,v 1.62 2004/10/15 10:43:45 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: misc.cpp,v 1.62.2.3 2005/01/10 15:30:26 dpage Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // misc.cpp - Miscellaneous Utilities
@@ -282,7 +282,7 @@ static bool needsQuoting(wxString& value, bool forTypes)
         while (pos < (int)value.length())
         {
             wxChar c=value.GetChar(pos);
-            if (!(c >= '0' && c <= '9') && 
+            if (!((pos > 0) && (c >= '0' && c <= '9')) && 
                 !(c >= 'a' && c  <= 'z') && 
                 !(c == '_'))
             {
@@ -525,7 +525,7 @@ void DisplayHelp(wxWindow *wnd, const wxString &helpTopic, char **icon)
         firstCall=false;
         wxString helpdir=docPath + wxT("/") + settings->GetCanonicalLanguage();
 
-        if (!wxFile::Exists(helpdir + wxT("/pgadmin3..hhp")) &&
+        if (!wxFile::Exists(helpdir + wxT("/pgadmin3.hhp")) &&
 #if defined(__WXMSW__) || wxUSE_LIBMSPACK
             !wxFile::Exists(helpdir + wxT("/pgadmin3.chm")) &&
 #endif
