@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: utffile.cpp,v 1.7 2004/10/29 09:29:30 andreas Exp $
-// Copyright (C) 2002 - 2004, The pgAdmin Development Team
+// RCS-ID:      $Id: utffile.cpp,v 1.7.2.2 2005/02/24 10:20:01 andreas Exp $
+// Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // utffile.cpp - file io with BOM interpretation
@@ -16,6 +16,10 @@ wxMBConvUTF16LE wxConvUTF16LE;
 extern wxMBConvUTF32BE wxConvUTF32BE;
 extern wxMBConvUTF32LE wxConvUTF32LE;
 
+#if !wxUSE_UNICODE
+#error utffile.cpp is implemented for unicode only.
+#endif
+
 
 // these are the magic characters identifying an Unicode file
 #define BOM_UTF8    "\357\273\277"
@@ -83,7 +87,7 @@ off_t wxUtfFile::Read(wxString &str, off_t nCount)
             if (decr)
                 Seek(-decr, wxFromCurrent);
 
-            m_conversion->MB2WC((wchar_t*)(wxChar*)wxStringBuffer(str, nLen), (const char*)buffer, (size_t)(nLen+1));
+            m_conversion->MB2WC((wchar_t*)(wxChar*)wxStringBuffer(str, nLen+1), (const char*)buffer, (size_t)(nLen+1));
         }
         else
             str = (wxChar*)buffer;
